//
//  ContentView.swift
//  VibratorDemo
//
//  Created by Apps4World on 1/8/22.
//

import SwiftUI
import VibratorKit

/// Demo view
struct ContentView: View {
    
    @StateObject var manager = DataManager()
    
    // MARK: - Main rendering function
    var body: some View {
        NavigationView {
            VStack {
                List(VibratorPattern.allCases) { pattern in
                    Label(pattern.rawValue, systemImage: "circle\(manager.selectedPattern == pattern ? ".fill" : "")")
                        .contentShape(Rectangle()).onTapGesture {
                            manager.selectedPattern = pattern
                        }
                }
                ControlsView
            }.navigationTitle("Demo")
        }
    }
    
    /// Controls
    private var ControlsView: some View {
        HStack(spacing: 60) {
            Button {
                manager.updateShuffleStatus()
            } label: {
                Image(systemName: "shuffle").opacity(manager.isShuffleOn ? 1 : 0.2)
            }
            
            Button {
                manager.startStopVibrator()
            } label: {
                Image(systemName: "power.circle\(manager.isVibratorOn ? ".fill" : "")")
            }

            Button {
                manager.updateRepeatStatus()
            } label: {
                Image(systemName: "repeat").opacity(manager.isRepeatOn ? 1 : 0.2)
            }
        }.frame(height: 50).font(.system(size: 25, weight: .bold))
    }
}

// MARK: - Preview UI
struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
